@@ -15,6 +15,6 @@ from .content_type import ContentType  # noqa: F401
 from .content_type_field import ContentTypeField  # noqa: F401
 
 
-__version__ = "2.11.0"
-__author__ = "Contentful GmbH (David Litvak Bruno)"
-__email__ = "david.litvak@contentful.com"
+__version__ = "2.15.0"
+__author__ = "Contentful GmbH"
+__email__ = "prd-ecosystem-dx@contentful.com"
