@@ -6,6 +6,7 @@ from .resource_builder import ResourceBuilder
 from .errors import get_error, RateLimitExceededError
 from .utils import ConfigurationException, retry_request
 
+from .tags_proxy import TagsProxy
 from .users_proxy import UsersProxy
 from .roles_proxy import RolesProxy
 from .assets_proxy import AssetsProxy
@@ -17,6 +18,8 @@ from .api_keys_proxy import ApiKeysProxy
 from .webhooks_proxy import WebhooksProxy
 from .snapshots_proxy import SnapshotsProxy
 from .environments_proxy import EnvironmentsProxy
+from .taxonomy_concepts_proxy import TaxonomyConceptsProxy
+from .taxonomy_concept_schemes_proxy import TaxonomyConceptSchemesProxy
 from .webhooks_call_proxy import WebhooksCallProxy
 from .ui_extensions_proxy import UIExtensionsProxy
 from .content_types_proxy import ContentTypesProxy
@@ -546,6 +549,58 @@ class Client(object):
 
         return EnvironmentsProxy(self, space_id)
 
+    def tags(self, space_id, environment_id):
+        """
+        Provides access to tag management methods.
+
+        API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/tags
+
+        :return: :class:`TagsProxy <contentful_management.tags_proxy.TagsProxy>` object.
+        :rtype: contentful.tags_proxy.TagsProxy
+
+        Usage:
+            >>> tags_proxy = client.tags('cfexampleapi', 'master')
+            <TagsProxy space_id="cfexampleapi" environment_id="master">
+        """
+
+        return TagsProxy(self, space_id, environment_id)
+
+    def taxonomy_concepts(self, organization_id):
+        """
+        Provides access to taxonomy concept management methods.
+
+        API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/taxonomy/concept
+
+        :param organization_id: The ID of the organization.
+        :type organization_id: string
+        :return: :class:`TaxonomyConceptsProxy <contentful_management.taxonomy_concepts_proxy.TaxonomyConceptsProxy>` object.
+        :rtype: contentful_management.taxonomy_concepts_proxy.TaxonomyConceptsProxy
+
+        Usage:
+
+            >>> taxonomy_concepts_proxy = client.taxonomy_concepts('organization_id')
+            <TaxonomyConceptsProxy organization_id="organization_id">
+        """
+        return TaxonomyConceptsProxy(self, organization_id)
+
+    def taxonomy_concept_schemes(self, organization_id):
+        """
+        Provides access to taxonomy concept scheme management methods.
+
+        API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/taxonomy/concept-scheme
+
+        :param organization_id: The ID of the organization.
+        :type organization_id: string
+        :return: :class:`TaxonomyConceptSchemesProxy <contentful_management.taxonomy_concept_schemes_proxy.TaxonomyConceptSchemesProxy>` object.
+        :rtype: contentful_management.taxonomy_concept_schemes_proxy.TaxonomyConceptSchemesProxy
+
+        Usage:
+
+            >>> taxonomy_concept_schemes_proxy = client.taxonomy_concept_schemes('organization_id')
+            <TaxonomyConceptSchemesProxy organization_id="organization_id">
+        """
+        return TaxonomyConceptSchemesProxy(self, organization_id)
+
     def _validate_configuration(self):
         """
         Validates that required parameters are present.
@@ -728,6 +783,15 @@ class Client(object):
 
         return self._http_request('put', url, kwargs)
 
+    def _http_patch(self, url, data, **kwargs):
+        """
+        Performs the HTTP PATCH request.
+        """
+
+        kwargs.update({'data': json.dumps(data)})
+
+        return self._http_request('patch', url, kwargs)
+
     def _http_delete(self, url, _data, **kwargs):
         """
         Performs the HTTP DELETE request.
@@ -788,6 +852,13 @@ class Client(object):
 
         return self._request('put', url, attributes, **kwargs)
 
+    def _patch(self, url, attributes=None, **kwargs):
+        """
+        Wrapper for the HTTP PATCH request.
+        """
+
+        return self._request('patch', url, attributes, **kwargs)
+
     def _delete(self, url, **kwargs):
         """
         Wrapper for the HTTP DELETE request.
