@@ -31,8 +31,11 @@ class ContentTypeField(object):
         self.omitted = field_data.get('omitted', False)
         self.required = field_data.get('required', False)
         self.disabled = field_data.get('disabled', False)
+        if field_data.get('defaultValue', None) is not None:
+            self.default_value = field_data.get('defaultValue')
         self.validations = [ContentTypeFieldValidation(v)
                             for v in field_data.get('validations', [])]
+        self.allowedResources = field_data.get('allowedResources')
         self._coercion = self._get_coercion()
 
     def to_json(self):
@@ -48,9 +51,12 @@ class ContentTypeField(object):
             'omitted': self.omitted,
             'required': self.required,
             'disabled': self.disabled,
-            'validations': [v.to_json() for v in self.validations]
+            'validations': [v.to_json() for v in self.validations],
         }
 
+        if hasattr(self, 'default_value'):
+            result['defaultValue'] = self.default_value
+
         if self.type == 'Array':
             result['items'] = self.items
 
