@@ -187,3 +187,14 @@ class RichTextField(BasicField):
         """
 
         return value
+
+
+class ResourceLinkField(BasicField):
+    """
+    ResourceLinkField
+
+    Nothing should be done here as ResourceLink does not support entity
+    resolution on the backend side and linked field can’t be used in
+    ordering and filtering queries.
+    """
+    pass
