@@ -3,21 +3,21 @@ from .locale import Locale
 
 
 """
-contentful.locales_proxy
-~~~~~~~~~~~~~~~~~~~~~~~
+contentful_management.locales_proxy
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 This module implements the LocalesProxy class.
 
-API Reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/locales
+API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/locales
 
-:copyright: (c) 2017 by Contentful GmbH.
+:copyright: (c) 2018 by Contentful GmbH.
 :license: MIT, see LICENSE for more details.
 """
 
 
 class LocalesProxy(ClientProxy):
     """
-    API Reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/locales
+    API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/locales
     """
 
     @property
@@ -25,6 +25,8 @@ class LocalesProxy(ClientProxy):
         return Locale
 
     def create(self, attributes=None, **kwargs):
-        """Creates a Locale with given attributes."""
+        """
+        Creates a locale with given attributes.
+        """
 
         return super(LocalesProxy, self).create(None, attributes)
