@@ -44,7 +44,7 @@ def string_class():
     depends on the Python version."""
     if sys.version_info[0] >= 3:
         return str
-    return basestring
+    return basestring # noqa: F821
 
 
 def json_error_class():
@@ -136,6 +136,7 @@ def base_path_for(resource_name):
     """
 
     return {
+        'Tag': 'tags',
         'Role': 'roles',
         'Space': 'spaces',
         'Asset': 'assets',
@@ -184,8 +185,7 @@ def str_type():
     if sys.version_info[0] >= 3:
         return str
 
-    global basestring
-    return basestring
+    return basestring # noqa: F821
 
 
 def sanitize_date(date):
