@@ -3,21 +3,21 @@ from .webhook import Webhook
 
 
 """
-contentful.webhooks_proxy
-~~~~~~~~~~~~~~~~~~~~~~~
+contentful_management.webhooks_proxy
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 This module implements the WebhooksProxy class.
 
-API Reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/webhooks
+API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/webhooks
 
-:copyright: (c) 2017 by Contentful GmbH.
+:copyright: (c) 2018 by Contentful GmbH.
 :license: MIT, see LICENSE for more details.
 """
 
 
 class WebhooksProxy(ClientProxy):
     """
-    API Reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/webhooks
+    API reference: https://www.contentful.com/developers/docs/references/content-management-api/#/reference/webhooks
     """
 
     @property
@@ -25,6 +25,8 @@ class WebhooksProxy(ClientProxy):
         return Webhook
 
     def create(self, attributes=None, **kwargs):
-        """Creates a Webhook with given attributes."""
+        """
+        Creates a webhook with given attributes.
+        """
 
         return super(WebhooksProxy, self).create(resource_id=None, attributes=attributes)
